==> tuia-news-center-api-0.0.16-xt-20180409.080828-3-sources.jar: cn/com/duiba/tuia/news/center/dto/req/SignInResultDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.io.Serializable;

import cn.com.duiba.tuia.news.center.enums.RewardUnit;

public class SignInResultDto implements Serializable {

    private static final long serialVersionUID = -1637082600752539242L;

    /** 是否是新用户 */
    private Boolean           newUser;

    /** 周期内连续签到天数 */
    private Integer           day;

    /** 奖金金额 */
    private Long              rewardFee;

    /** 奖励单位 */
    private RewardUnit        rewardUnit;

    /** 连续签到天数 */
    private Integer           continuedDays;

    /**明天的签到奖励*/
    private RewardUnit        tomorrowRewardUnit;

    /**明天签到的奖励最大数额*/
    private Long              tomorrowrewardFee;

    public RewardUnit getTomorrowRewardUnit() {
        return tomorrowRewardUnit;
    }

    public void setTomorrowRewardUnit(RewardUnit tomorrowRewardUnit) {
        this.tomorrowRewardUnit = tomorrowRewardUnit;
    }

    public Long getTomorrowrewardFee() {
        return tomorrowrewardFee;
    }

    public void setTomorrowrewardFee(Long tomorrowrewardFee) {
        this.tomorrowrewardFee = tomorrowrewardFee;
    }

    public Integer getContinuedDays() {
        return continuedDays;
    }

    public void setContinuedDays(Integer continuedDays) {
        this.continuedDays = continuedDays;
    }

    public Boolean getNewUser() {
        return newUser;
    }

    public void setNewUser(Boolean newUser) {
        this.newUser = newUser;
    }

    public Integer getDay() {
        return day;
    }

    public void setDay(Integer day) {
        this.day = day;
    }

    public Long getRewardFee() {
        return rewardFee;
    }

    public void setRewardFee(Long rewardFee) {
        this.rewardFee = rewardFee;
    }

    public RewardUnit getRewardUnit() {
        return rewardUnit;
    }

    public void setRewardUnit(RewardUnit rewardUnit) {
        this.rewardUnit = rewardUnit;
    }
}

==> tuia-news-center-api-0.0.53-xt6-20180727.083357-1-sources.jar: cn/com/duiba/tuia/news/center/dto/req/SignInResultDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.io.Serializable;

import cn.com.duiba.tuia.news.center.enums.RewardUnit;

public class SignInResultDto implements Serializable {

    private static final long serialVersionUID = -1637082600752539242L;

    /** 是否是新用户 */
    private Boolean           newUser;

    /** 周期内连续签到天数 */
    private Integer           day;

    /** 奖金金额 */
    private Long              rewardFee;

    /** 奖励单位 */
    private RewardUnit        rewardUnit;

    /** 连续签到天数 */
    private Integer           continuedDays;

    /**明天的签到奖励*/
    private RewardUnit        tomorrowRewardUnit;

    /**明天签到的奖励最大数额*/
    private Long              tomorrowrewardFee;

    /**外部奖励title*/
    private String            rewardTitle;

    /**外部奖励文案*/
    private String            rewardContent;

    public String getRewardTitle() {
        return rewardTitle;
    }

    public void setRewardTitle(String rewardTitle) {
        this.rewardTitle = rewardTitle;
    }

    public String getRewardContent() {
        return rewardContent;
    }

    public void setRewardContent(String rewardContent) {
        this.rewardContent = rewardContent;
    }

    public RewardUnit getTomorrowRewardUnit() {
        return tomorrowRewardUnit;
    }

    public void setTomorrowRewardUnit(RewardUnit tomorrowRewardUnit) {
        this.tomorrowRewardUnit = tomorrowRewardUnit;
    }

    public Long getTomorrowrewardFee() {
        return tomorrowrewardFee;
    }

    public void setTomorrowrewardFee(Long tomorrowrewardFee) {
        this.tomorrowrewardFee = tomorrowrewardFee;
    }

    public Integer getContinuedDays() {
        return continuedDays;
    }

    public void setContinuedDays(Integer continuedDays) {
        this.continuedDays = continuedDays;
    }

    public Boolean getNewUser() {
        return newUser;
    }

    public void setNewUser(Boolean newUser) {
        this.newUser = newUser;
    }

    public Integer getDay() {
        return day;
    }

    public void setDay(Integer day) {
        this.day = day;
    }

    public Long getRewardFee() {
        return rewardFee;
    }

    public void setRewardFee(Long rewardFee) {
        this.rewardFee = rewardFee;
    }

    public RewardUnit getRewardUnit() {
        return rewardUnit;
    }

    public void setRewardUnit(RewardUnit rewardUnit) {
        this.rewardUnit = rewardUnit;
    }
}
